Yo

Derive Macro Yo 

#[derive(Yo)]
{
    // Attributes available to this derive:
    #[yo]
}
Write a type’s shape, its document encoding and the indexes it declares.

See the doc module for the attributes and what they mean. Write a type’s shape, its document encoding and its indexes.

See the module docs for what the attributes mean.