pub trait Indexed {
const INDEXES: &'static [(&'static str, IndexKind)];
const VECTORS: &'static [(&'static str, usize)] = _;
}Expand description
The indexes a type declares.
Written by #[derive(Yo)] for every type it is put on, whether or not the
type has an id, because an edge type declares indexes and has no id. That is
the whole reason this is a trait of its own rather than a constant on
Document.
Required Associated Constants
Provided Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".