pub fn at<V: Field>(d: Doc<'_>, name: &str) -> Result<V>Expand description
Read one field out of a document, which is what the derive calls per field.
Errors
Code::Corrupt if the field is missing and its type is not an Option,
or if it is there and is the wrong type.